@@ -12,6 +12,8 @@ use {
         kitty,
         launchable::Launchable,
         path::closest_dir,
+        pattern::InputPattern,
+        preview::PreviewState,
         skin::*,
         stage::Stage,
         syntactic::SyntaxTheme,
@@ -79,22 +81,26 @@ impl App {
         con: &AppContext,
     ) -> Result<App, ProgramError> {
         let screen = Screen::new(con)?;
+        let mut browser_state = Box::new(
+            BrowserState::new(
+                con.initial_root.clone(),
+                con.initial_tree_options.clone(),
+                screen,
+                con,
+                &Dam::unlimited(),
+            )?
+        );
+        if let Some(path) = con.initial_file.as_ref() {
+            browser_state.tree.try_select_path(path);
+        }
         let panel = Panel::new(
             PanelId::from(0),
-            Box::new(
-                BrowserState::new(
-                    con.initial_root.clone(),
-                    con.initial_tree_options.clone(),
-                    screen,
-                    con,
-                    &Dam::unlimited(),
-                )?
-            ),
+            browser_state,
             Areas::create(&mut Vec::new(), 0, screen, false),
             con,
         );
         let (tx_seqs, rx_seqs) = unbounded::<Sequence>();
-        Ok(App {
+        let mut app = App {
             screen,
             active_panel_idx: 0,
             panels: panel.into(),
@@ -107,7 +113,30 @@ impl App {
             tx_seqs,
             rx_seqs,
             drawing_count: 0,
-        })
+        };
+        if let Some(path) = con.initial_file.as_ref() {
+            // open initial_file in preview
+            let preview_state = Box::new(PreviewState::new(
+                path.to_path_buf(),
+                InputPattern::none(),
+                None,
+                con.initial_tree_options.clone(),
+                con,
+            ));
+            if let Err(err) = app.new_panel(
+                preview_state,
+                PanelPurpose::Preview,
+                HDir::Right,
+                false,
+                con,
+            ) {
+                warn!("could not open preview: {err}");
+            } else {
+                // we focus the preview panel
+                app.active_panel_idx = 1;
+            }
+        }
+        Ok(app)
     }
 
     fn panel_ref_to_idx(&self, panel_ref: PanelReference) -> Option<usize> {
@@ -336,6 +365,12 @@ impl App {
             HandleInApp(internal) => {
                 debug!("handling internal {internal:?} at app level");
                 match internal {
+                    Internal::escape => {
+                        let mode = self.panel().state().get_mode();
+                        let cmd = self.mut_panel().input.escape(con, mode);
+                        debug!("cmd on escape: {cmd:?}");
+                        self.apply_command(w, cmd, panel_skin, app_state, con)?;
+                    }
                     Internal::panel_left_no_open | Internal::panel_right_no_open => {
                         let new_active_panel_idx = if internal == Internal::panel_left_no_open {
                             // we're here because the state wants us to either move to the panel
